@@ -1,6 +1,6 @@
 #package Sim::OPT::Interlinear;
 
-# INTERLINEAR, v. 0.03
+# INTERLINEAR, v. 0.009
 # Author: Gian Luca Brunetti, Politecnico di Milano. (gianluca.brunetti@polimi.it)
 # Copyright reserved.  2018.
 # GPL License 3.0 or newer.
@@ -31,7 +31,7 @@ no warnings;
 our @ISA = qw( Exporter );
 our @EXPORT = qw( interlinear, interstart );
 
-$VERSION = '0.007';
+$VERSION = '0.009';
 $ABSTRACT = 'Interlinear is a program for building metamodels from incomplete, multivariate, discrete dataseries.';
 
 #######################################################################
@@ -39,7 +39,6 @@ $ABSTRACT = 'Interlinear is a program for building metamodels from incomplete, m
 #######################################################################
 
 
-
 my $maxloops= 1000;
 my $sourcefile = "/home/luca/int/starcloud_small.csv";
 my $newfile = $sourcefile . "_new.csv";
@@ -74,9 +73,22 @@ my $minreq_formerge = 0; # THIS VALUE SPECIFIES A STRENGTH VALUE (LEVEL OF RELIA
 my $minimumcertain = 0; # WHAT IS THE MINIMUM LEVEL OF STRENGTH (LEVEL OF RELIABILITY) REQUIRED TO USE A DATUM TO BUILD UPON IT. IT DEPENDS ON THE DISTANCE FROM THE ORIGINS OF THE DATUM. THE LONGER THE DISTANCE, THE SMALLER THE STRENGTH (WHICH IS INDEED INVERSELY PROPORTIONAL). A STENGTH VALUE OF 1 IS OF A SIMULATED DATUM, NOT OF A DERIVED DATUM. If 0, no entry barrier.
 my $minimumhold = 1; # WHAT IS THE MINIMUM LEVEL OF STRENGTH (LEVEL OF RELIABILITY) REQUIRED FOR NOT AVERAGING A DATUM WITH ANOTHER, DERIVED DATUM. USUALLY IT HAS TO BE KEPT EQUAL TO $minimimcertain.  If 1, ONLY THE MODEL DATA ARE NOT SUBSTITUTABLE IN THE METAMODEL.
 my $condweight = "yes"; # THIS CONDITIONS TELLS IF THE STRENGTH (LEVEL OF RELIABILITY) OF THE GRADIENTS HAS TO BE CUMULATIVELY TAKEN INTO ACCOUNT IN THE WEIGHTING CALCULATIONS.
+
 #######################################################################
 
 
+sub odd
+{
+  my ( $number ) = @_;
+  if ( $number % 2 == 1 )
+  {
+    return ( "odd" );
+  }
+  else
+  {
+    return ( "even" );
+  }
+}
 
 
 sub tellstepsize
@@ -170,50 +182,67 @@ sub adjustmode
 
 sub preparearr
 {
-  my @lines = @_;
-  foreach my $line ( @lines )
+  my ( $lines_ref, $optformat ) = @_;
+  my @lines = @{ $lines_ref };
+  if ( $lines[1] =~ /_/ )
   {
-    my ( @row, @pars );
-    my ( $header );
-    chomp( $line );
-    if ( $line =~ /_/ )
+    foreach my $line ( @lines )
     {
-      @row = split( /,/ , $line );
+      chomp( $line );
+      my @row = split( /,/ , $line );
       @pars = split( /_/ , $row[0] );
-      $header = $row[0];
+      if ( $row[1] eq undef )
+      {
+        push ( @arr, [ $row[0], [ @pars ] ] );
+      }
+      else
+      {
+        push ( @arr, [ $row[0], [ @pars ], $row[1], 1 ] );
+      }
     }
-    else
+  }
+  else
+  {
+    $optformat = "no";
+    my @arrnumbers;
+    foreach my $line ( @lines )
     {
-      @row = split( /,/ , $line );
-      $rightnum = scalar( @row - 1 );
+      chomp( $line );
+      my @row = split( /,/ , $line );
+      @arrnumbers;
+      push ( @arrnumbers , scalar( @row ) );
+    }
+    my $maxnum = max( @arrnumbers );
+
+    foreach my $line ( @lines )
+    {
+      my @row = split( /,/ , $line );
+      my $rightnum = ( $maxnum - 1 );
       my $count = 1;
-      while ( $count < $rightnum )
+      my @pars;
+      while ( $count <= $rightnum )
       {
         my $bit = join( "-", ( $count, $row[$count-1] ) );
         push( @pars, $bit );
         $count++;
       }
-      $header = join( "_", @pars )
-    }
+      my $header = join( "_", @pars );
 
-    if ( $row[1] eq undef )
-    {
-      push ( @arr, [ $header, [ @pars ] ] );
-    }
-    else
-    {
-      push ( @arr, [ $header, [ @pars ], $row[1], 1 ] );
+      if ( scalar( @row ) < $maxnum )
+      {
+        push ( @arr, [ $header, [ @pars ] ] );
+      }
+      else
+      {
+        push ( @arr, [ $header, [ @pars ], $row[-1], 1 ] );
+      }
     }
   } #say $tee "ARR: " . dump( @arr );
-  return( \@arr );
+  return( \@arr, $optformat );
 }
 
 
 
-
-
-
-
 sub pythagoras
 {
   my ( $factbag_ref, $levbag_ref, $stepbag_ref ) = @_;
@@ -457,7 +486,7 @@ sub calcdist
       $strength = ( $strength * $el3 * $elt3 );
     }
 
-    return( { dist => $dist, strength => $strength, ordist => $ordist, rawdist => $rawdist, diff1 => \@diff1, diff2 => \@diff2, da1 => \@da1, da2 => \@da2, da1par => \@da1par, da2par => \@da2par } );
+    return( { dist => $disfactlevelst, strength => $strength, ordist => $ordist, rawdist => $rawdist, diff1 => \@diff1, diff2 => \@diff2, da1 => \@da1, da2 => \@da2, da1par => \@da1par, da2par => \@da2par } );
   }
 }
 
@@ -810,7 +839,7 @@ sub wei
                         {
                           my $soughtval = ( $elt->[2] + ( $elt->[2] * $soughtinc ) );
                           push ( @{ $wand{$key}{vals} }, $soughtval );
-                          push ( @{ $wand{$key}{dists} }, $totdist );say $tee "FACTLEVELS: " . dump( %factlevels );
+                          push ( @{ $wand{$key}{dists} }, $totdist );
                           #say $tee "PUSHING \$soughtval $soughtval INTO \@{ \$wand{\$key}{vals} }: " . dump( @{ $wand{\$key}{vals} } ) . " BECAUSE KEY: $key . " ;
 
                           #my $strength = ( ( $elt->[3] ** $totstrength ) ** ( 1/2 ) );
@@ -1265,6 +1294,22 @@ sub mixlimbo
 }
 
 
+sub prepfactlev
+{
+  my @aarr = @_;
+  my %hsh;
+  foreach my $el ( @aarr )
+  {
+    foreach my $bit ( @{ $el->[1] } )
+    {
+      my ( $head, $tail ) = split( /-/ , $bit );
+      $hsh{pairs}{$head} = $tail;
+    }
+  }
+  return( %hsh );
+}
+
+
 sub interstart
 {
 say "
@@ -1307,26 +1352,12 @@ sub interlinear
   my @lines = <SOURCEFILE>;
   close SOURCEFILE;
 
-  my ( $aarr_ref, $aarrcopy_ref ) = preparearr( @lines );
+  my $optform = "yes";
+
+  my ( $aarr_ref, $optformat ) = preparearr( \@lines, $optform );
 
   my @aarr = @{ $aarr_ref };
 
-
-  sub prepfactlev
-  {
-    my @aarr = @_;
-    my %hsh;
-    foreach my $el ( @aarr )
-    {
-      foreach my $bit ( @{ $el->[1] } )
-      {
-        my ( $head, $tail ) = split( /-/ , $bit );
-        $hsh{pairs}{$head} = $tail;
-      }
-    }
-    return( %hsh );
-  }
-
   my %factlevels = prepfactlev( @aarr );
 
   my ( $factlev_ref ) = tellstepsize( \%factlevels );
@@ -1477,17 +1508,28 @@ if ( @ARGV )
 open( NEWFILE, ">$newfile" ) or die;
 foreach my $entry ( @arr )
 {
-  my $coun = 0;
   my $number = scalar( @{ $entry->[1] } );
+  my $coun = 0;
   foreach my $item ( @{ $entry->[1] } )
   {
-    if ( ( not ( $coun == $number ) ) and ( not ( $coun == ( $number -1 ) ) ) )
+    if ( $optformat eq "yes" )
     {
-      print NEWFILE "$item" . "_";
+      if ( ( not ( $coun == $number ) ) and ( not ( $coun == ( $number -1 ) ) ) )
+      {
+        print NEWFILE "$item" . "_";
+      }
+      else
+      {
+        print NEWFILE "$item" . ",";
+      }
     }
-    else
+    elsif ( $optformat eq "no" )
     {
-      print NEWFILE "$item" . ",";
+      my $response = odd( $coun );
+      if ( $response eq "odd" )
+      {
+        print NEWFILE "$item,";
+      }
     }
     $coun++;
   }
@@ -1505,10 +1547,13 @@ __END__
 
 =head1 NAME
 
+
 Sim::OPT::Interlinear
 
+
 =head1 SYNOPSIS
 
+
   From Perl (via "re.pl" or in a Perl program):
   interlinear( "/path/to/a/pre-prepared-configfile.pl", "/path/to/a/pre-prepared-sourcefile.csv" );
   or from the command line:
@@ -1518,8 +1563,10 @@ Sim::OPT::Interlinear
   interlinear interstart
   to begin with a dialogue question.
 
+
 =head1 DESCRIPTION
 
+
 Interlinear is a program for computing the missing values in multivariate datasieries pre-prepared in csv format.
 The program can adopt the following algorithmic strategies and intermix their result:
 
@@ -1588,18 +1635,26 @@ After some computations, Interlinear will output a new dataseries, with the miss
 
 =head2 EXPORT
 
+
 interlinear, interstart.
 
+
 =head1 SEE ALSO
 
+
 An example of configuration file can be found in the "examples" folder in this distribution.
 
+
 =head1 AUTHOR
 
+
 Gian Luca Brunetti, E<lt>gianluca.brunetti@polimi.itE<gt>
 
+
 =head1 COPYRIGHT AND LICENSE
 
+
 Copyright (C) 2018 by Gian Luca Brunetti and Politecnico di Milano. This is free software. You can redistribute it and/or modify it under the terms of the GNU General Public License as published by the Free Software Foundation, version 3 or newer.
 
+
 =cut
